@@ -51,10 +51,29 @@ ssd_dists_bcanz <- function(npars = c(2L, 5L)) {
 #' @export
 #' @examples
 #' ssd_fit_bcanz(ssddata::ccme_boron)
-ssd_fit_bcanz <- function(data, left = "Conc", dists = ssd_dists_bcanz()) {
+ssd_fit_bcanz <- function(data, left = "Conc", ..., dists = ssd_dists_bcanz()) {
+  chk_data(data)
+  chk_unused(...)
+  chk_subset(dists, ssd_dists_bcanz())
+
+  ## all arguments manually specified to ensure robust to
+  ## changes in default values in ssd_fit_dists()
   ssd_fit_dists(data,
     left = left,
-    dists = dists
+    right = left,
+    weight = NULL,
+    dists = dists,
+    nrow = 6L,
+    rescale = FALSE,
+    reweight = FALSE,
+    computable = FALSE,
+    at_boundary_ok = TRUE,
+    all_dists = FALSE,
+    min_pmix = ssd_min_pmix(nrow(data)),
+    range_shape1 = c(0.05, 20),
+    range_shape2 = c(0.05, 20),
+    control = list(),
+    silent = FALSE
   )
 }
 
@@ -73,12 +92,22 @@ ssd_fit_bcanz <- function(data, left = "Conc", dists = ssd_dists_bcanz()) {
 #' @examples
 #' fits <- ssd_fit_bcanz(ssddata::ccme_boron)
 #' ssd_hc_bcanz(fits, nboot = 100)
-ssd_hc_bcanz <- function(x, nboot = 10000, min_pboot = 0.95) {
+ssd_hc_bcanz <- function(x, ..., nboot = 10000, min_pboot = 0.95) {
+  chk_unused(...)
   ssd_hc(x,
     proportion = c(0.01, 0.05, 0.1, 0.2),
+    average = TRUE,
     ci = TRUE,
+    level = 0.95,
     nboot = nboot,
-    min_pboot = min_pboot
+    min_pboot = min_pboot,
+    est_method = "multi",
+    ci_method = "weighted_samples",
+    parametric = TRUE,
+    delta = 9.21,
+    samples = FALSE,
+    save_to = NULL,
+    control = NULL
   )
 }
 
@@ -89,6 +118,7 @@ ssd_hc_bcanz <- function(x, nboot = 10000, min_pboot = 0.95) {
 #' This function can take several minutes to run with recommended 10,000 iterations.
 #'
 #' @inheritParams params
+#' @inheritParams ssd_hp
 #' @return A tibble of corresponding hazard concentrations.
 #' @seealso [`ssd_hp()`].
 #' @family BCANZ
@@ -96,11 +126,31 @@ ssd_hc_bcanz <- function(x, nboot = 10000, min_pboot = 0.95) {
 #' @examples
 #' fits <- ssd_fit_bcanz(ssddata::ccme_boron)
 #' ssd_hp_bcanz(fits, nboot = 100)
-ssd_hp_bcanz <- function(x, conc = 1, nboot = 10000, min_pboot = 0.95) {
+ssd_hp_bcanz <- function(x, conc = 1, ..., nboot = 10000, min_pboot = 0.95, proportion = FALSE) {
+  chk_unused(...)
+
+  if (missing(proportion) || isFALSE(proportion)) {
+    lifecycle::deprecate_soft(
+      "2.3.1", I("ssd_hp(proportion = FALSE)"), I("ssd_hp(proportion = TRUE)"),
+      "Please set the `proportion` argument to `ssd_hp_bcanz()` to be TRUE which will cause it to return hazard proportions instead of percentages then update your downstream code accordingly."
+    )
+  }
+  chk_flag(proportion)
+
   ssd_hp(x,
     conc = conc,
+    average = TRUE,
     ci = TRUE,
+    level = 0.95,
     nboot = nboot,
-    min_pboot = min_pboot
+    min_pboot = min_pboot,
+    est_method = "multi",
+    ci_method = "weighted_samples",
+    parametric = TRUE,
+    delta = 9.21,
+    proportion = proportion,
+    samples = FALSE,
+    save_to = NULL,
+    control = NULL
   )
 }
