@@ -1,6 +1,6 @@
 # Copyright 2015-2023 Province of British Columbia
 # Copyright 2021 Environment and Climate Change Canada
-# Copyright 2023-2024 Australian Government Department of Climate Change,
+# Copyright 2023-2025 Australian Government Department of Climate Change,
 # Energy, the Environment and Water
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
@@ -22,6 +22,8 @@
 #'   \item{dist}{The distribution name (chr)}
 #'   \item{aic}{Akaike's Information Criterion (dbl)}
 #'   \item{bic}{Bayesian Information Criterion (dbl)}
+#'   \item{at_bound}{Parameter(s) at boundary (lgl)}
+#'   \item{computable}{All parameter have computable standard errors (lgl)}
 #' }
 #' and if the data are non-censored
 #' \describe{
@@ -36,9 +38,9 @@
 #' In the case of an object of class fitdists the function also returns
 #' \describe{
 #'   \item{delta}{The Information Criterion differences (dbl)}
-#'   \item{weight}{The Information Criterion weights (dbl)}
+#'   \item{wt}{The Information Criterion weights (dbl)}
 #' }
-#' where `delta` and `weight` are based on `aic` for censored data
+#' where `delta` and `wt` are based on `aic` for censored data
 #' and `aicc` for non-censored data.
 #'
 #' @inheritParams params
@@ -66,26 +68,43 @@ ssd_gof <- function(x, ...) {
 #' @describeIn ssd_gof Goodness of Fit
 #' @export
 #' @examples
-#' ssd_gof(fits, pvalue = TRUE)
-ssd_gof.fitdists <- function(x, pvalue = FALSE, ...) {
-  chk_flag(pvalue)
+#' ssd_gof(fits, pvalue = TRUE, wt = TRUE)
+ssd_gof.fitdists <- function(x, ..., pvalue = FALSE, wt = FALSE) {
   chk_unused(...)
+  chk_flag(pvalue)
 
-  glance <- glance(x)
-  glance$bic <- -2 * glance$log_lik + log(glance$nobs) * glance$npars
+  if (vld_flag(wt) && !wt) {
+    lifecycle::deprecate_soft(
+      "2.3.1", I("ssd_gof(wt = FALSE)"), I("ssd_gof(wt = TRUE)"),
+      "Please set the `wt` argument to `ssd_gof()` to be TRUE which will rename the 'weight' column to 'wt' and then update your downstream code accordingly."
+    )
+  }
+  chk_flag(wt)
 
-  if (is.na(glance$nobs[1] || glance$nobs[1] < 8)) {
-    glance$ad <- NA_real_
-    glance$ks <- NA_real_
-    glance$cvm <- NA_real_
+  gof <- glance(x, wt = TRUE)
+  gof$bic <- -2 * gof$log_lik + log(gof$nobs) * gof$npars
+
+  if (is.na(gof$nobs[1] || gof$nobs[1] < 8)) {
+    gof$ad <- NA_real_
+    gof$ks <- NA_real_
+    gof$cvm <- NA_real_
   } else {
     data <- .data_fitdists(x)
     tests <- lapply(x, .tests_tmbfit, data = data, pvalue = pvalue)
-    tests <- bind_rows(tests)
-    glance <- cbind(glance, tests)
-    glance <- as_tibble(glance)
+    tests <- dplyr::bind_rows(tests)
+    gof <- cbind(gof, tests)
+    gof <- as_tibble(gof)
   }
-  glance$weight <- round(glance$weight, 3)
-  glance$delta <- round(glance$delta, 3)
-  glance[c("dist", "ad", "ks", "cvm", "aic", "aicc", "bic", "delta", "weight")]
+  gof$wt <- round(gof$wt, 3)
+  gof$delta <- round(gof$delta, 3)
+  gof[c("dist", "ad", "ks", "cvm", "aic", "aicc", "bic", "delta", "wt")]
+
+  if (!wt) {
+    gof <- dplyr::rename(gof, weight = "wt")
+  }
+
+  ## after in case old fit object and not have at_boundary or computable flags.
+  gof$at_bound <- ssd_at_boundary(x)
+  gof$computable <- ssd_computable(x)
+  gof
 }
