@@ -17,53 +17,59 @@
 
 test_that("ssd_hc_burrlioz deprecated", {
   fit <- ssd_fit_burrlioz(ssddata::ccme_boron)
-  set.seed(47)
-  expect_defunct(hc_boron <- ssd_hc_burrlioz(fit, nboot = 10, ci = TRUE, min_pboot = 0))
+  withr::with_seed(50, {
+    expect_defunct(hc_boron <- ssd_hc_burrlioz(fit, nboot = 10, ci = TRUE, min_pboot = 0))
+  })
 })
 
 test_that("ssd_hc gets estimates with invpareto", {
   fit <- ssd_fit_burrlioz(ssddata::ccme_boron)
-  set.seed(47)
-  hc_boron <- ssd_hc(fit, nboot = 10, ci = TRUE, min_pboot = 0, samples = TRUE)
+  withr::with_seed(50, {
+    hc_boron <- ssd_hc(fit, nboot = 10, ci = TRUE, min_pboot = 0, samples = TRUE)
+  })
   expect_snapshot_data(hc_boron, "hc_boron")
 })
 
 test_that("ssd_hc gets estimates with invpareto no ci", {
   fit <- ssd_fit_burrlioz(ssddata::ccme_boron)
-  set.seed(47)
-  hc_boron <- ssd_hc(fit, nboot = 10, ci = FALSE, min_pboot = 0)
+  withr::with_seed(47, {
+    hc_boron <- ssd_hc(fit, nboot = 10, ci = FALSE, min_pboot = 0)
+  })
   expect_snapshot_data(hc_boron, "hc_boron_no_ci")
 })
 
 test_that("ssd_hc gets estimates with burrIII3", {
-  set.seed(99)
-  data <- data.frame(Conc = ssd_rburrIII3(30))
+  withr::with_seed(99, {
+    data <- data.frame(Conc = ssd_rburrIII3(30))
+  })
   fit <- ssd_fit_burrlioz(data)
   expect_identical(names(fit), "burrIII3")
-  set.seed(49)
-  hc_burrIII3 <- ssd_hc(fit, nboot = 10, ci = TRUE, min_pboot = 0, samples = TRUE)
+  withr::with_seed(49, {
+    hc_burrIII3 <- ssd_hc(fit, nboot = 10, ci = TRUE, min_pboot = 0, samples = TRUE)
+  })
   expect_snapshot_data(hc_burrIII3, "hc_burrIII3")
 })
 
 test_that("ssd_hc currently errors with burrIII3", {
-  set.seed(99)
-  data <- data.frame(Conc = ssd_rburrIII3(30))
+  withr::with_seed(50, {
+    data <- data.frame(Conc = ssd_rburrIII3(30))
+  })
   fit <- ssd_fit_burrlioz(data)
   expect_identical(names(fit), "burrIII3")
-  set.seed(47)
   # FIXME: currently errors - also hp
-  expect_error(hc_burrIII3 <- ssd_hc(fit, nboot = 10, ci = TRUE, min_pboot = 0))
+  withr::with_seed(50, {
+    expect_error(hc_burrIII3 <- ssd_hc(fit, nboot = 10, ci = TRUE, min_pboot = 0))
+  })
 })
 
 test_that("ssd_hc gets estimates with burrIII3 parametric", {
-  set.seed(99)
-  data <- data.frame(Conc = ssd_rburrIII3(30))
+  withr::with_seed(99, {
+    data <- data.frame(Conc = ssd_rburrIII3(30))
+  })
   fit <- ssd_fit_burrlioz(data)
   expect_identical(names(fit), "burrIII3")
-  set.seed(49)
-  hc_burrIII3 <- ssd_hc(fit,
-    nboot = 10, ci = TRUE, min_pboot = 0,
-    parametric = TRUE, samples = TRUE
-  )
+  withr::with_seed(49, {
+    hc_burrIII3 <- ssd_hc(fit, nboot = 10, ci = TRUE, min_pboot = 0, parametric = TRUE, samples = TRUE)
+  })
   expect_snapshot_data(hc_burrIII3, "hc_burrIII3_parametric")
 })
