@@ -17,47 +17,56 @@
 
 test_that("ssd_hp_burrlioz gets estimates with invpareto", {
   fit <- ssd_fit_burrlioz(ssddata::ccme_boron)
-  set.seed(47)
-  hp_boron <- ssd_hp(fit, nboot = 10, ci = TRUE, min_pboot = 0, samples = TRUE)
+  withr::with_seed(47, {
+    hp_boron <- ssd_hp(fit, nboot = 10, ci = TRUE, min_pboot = 0, samples = TRUE, proportion = FALSE)
+  })
   expect_snapshot_data(hp_boron, "hp_boron")
 })
 
 test_that("ssd_hp_burrlioz gets estimates with invpareto no ci", {
   fit <- ssd_fit_burrlioz(ssddata::ccme_boron)
-  set.seed(47)
-  hp_boron <- ssd_hp(fit, nboot = 10, ci = FALSE, min_pboot = 0)
+  withr::with_seed(47, {
+    hp_boron <- ssd_hp(fit, nboot = 10, ci = FALSE, min_pboot = 0, proportion = FALSE)
+  })
   expect_snapshot_data(hp_boron, "hp_boron_no_ci")
 })
 
 test_that("ssd_hp_burrlioz gets estimates with burrIII3", {
-  set.seed(99)
-  data <- data.frame(Conc = ssd_rburrIII3(30))
+  withr::with_seed(99, {
+    data <- data.frame(Conc = ssd_rburrIII3(30))
+  })
   fit <- ssd_fit_burrlioz(data)
   expect_identical(names(fit), "burrIII3")
-  set.seed(49)
-  hp_burrIII3 <- ssd_hp(fit, nboot = 10, ci = TRUE, min_pboot = 0, samples = TRUE)
+  withr::with_seed(49, {
+    hp_burrIII3 <- ssd_hp(fit, nboot = 10, ci = TRUE, min_pboot = 0, samples = TRUE, proportion = FALSE)
+  })
   expect_snapshot_data(hp_burrIII3, "hp_burrIII3")
 })
 
 test_that("ssd_hp_burrlioz currently errors!", {
-  set.seed(99)
-  data <- data.frame(Conc = ssd_rburrIII3(30))
+  withr::with_seed(99, {
+    data <- data.frame(Conc = ssd_rburrIII3(30))
+  })
   fit <- ssd_fit_burrlioz(data)
   expect_identical(names(fit), "burrIII3")
-  set.seed(47)
   # FIXME: currently errors!
-  expect_error(hp_burrIII3 <- ssd_hp(fit, nboot = 10, ci = TRUE, min_pboot = 0))
+  withr::with_seed(47, {
+    expect_error(hp_burrIII3 <- ssd_hp(fit, nboot = 10, ci = TRUE, min_pboot = 0, proportion = FALSE))
+  })
 })
 
 test_that("ssd_hp_burrlioz gets estimates with burrIII3 parametric", {
-  set.seed(99)
-  data <- data.frame(Conc = ssd_rburrIII3(30))
+  withr::with_seed(99, {
+    data <- data.frame(Conc = ssd_rburrIII3(30))
+  })
   fit <- ssd_fit_burrlioz(data)
   expect_identical(names(fit), "burrIII3")
-  set.seed(49)
-  hp_burrIII3 <- ssd_hp(fit,
-    nboot = 10, ci = TRUE, min_pboot = 0,
-    parametric = TRUE, samples = TRUE
-  )
+  withr::with_seed(49, {
+    hp_burrIII3 <- ssd_hp(fit,
+      nboot = 10, ci = TRUE, min_pboot = 0,
+      parametric = TRUE, samples = TRUE,
+      proportion = FALSE
+    )
+  })
   expect_snapshot_data(hp_burrIII3, "hp_burrIII3_parametric")
 })
