@@ -17,10 +17,11 @@
 
 test_that("lnorm_lnorm", {
   test_dist("lnorm_lnorm", qroottolerance = 1e-04)
-  expect_equal(ssd_plnorm_lnorm(1), 0.329327626965729)
-  expect_equal(ssd_qlnorm_lnorm(0.75), 3.53332370752762)
-  set.seed(42)
-  expect_equal(ssd_rlnorm_lnorm(2), c(0.568531719998709, 1.43782047983794))
+  expect_snapshot_value(ssd_plnorm_lnorm(1), style = "deparse")
+  expect_snapshot_value(ssd_qlnorm_lnorm(0.75), style = "deparse")
+  withr::with_seed(50, {
+    expect_snapshot_value(ssd_rlnorm_lnorm(2), style = "deparse")
+  })
 })
 
 test_that("ssd_qlnorm_lnorm allows reversed distributions", {
@@ -38,23 +39,25 @@ test_that("ssd_plnorm_lnorm allows reversed distributions", {
 })
 
 test_that("ssd_rlnorm_lnorm allows reversed distributions", {
-  set.seed(10)
-  r1 <- ssd_rlnorm_lnorm(1, meanlog1 = 0, meanlog2 = 1, pmix = 0.1)
-  set.seed(10)
-  r2 <- ssd_rlnorm_lnorm(1, meanlog1 = 1, meanlog2 = 0, pmix = 0.9)
+  withr::with_seed(50, {
+    r1 <- ssd_rlnorm_lnorm(1, meanlog1 = 0, meanlog2 = 1, pmix = 0.1)
+  })
+  withr::with_seed(50, {
+    r2 <- ssd_rlnorm_lnorm(1, meanlog1 = 1, meanlog2 = 0, pmix = 0.9)
+  })
   expect_equal(r1, r2)
 })
 
 test_that("lnorm_lnorm positive q with extreme distribution", {
-  expect_equal(qlnorm_lnorm_ssd(0.05,
+  expect_snapshot_value(qlnorm_lnorm_ssd(0.05,
     meanlog1 = -10.39362, sdlog1 = 0.399835,
     meanlog2 = -4.76721, sdlog2 = 2.583824, pmix = 0.1308133
-  ), 2.49076867209839e-05)
+  ), style = "deparse")
 })
 
 test_that("lnorm_lnorm positive q with extreme large distribution", {
-  expect_equal(qlnorm_lnorm_ssd(0.99,
+  expect_snapshot_value(qlnorm_lnorm_ssd(0.99,
     meanlog1 = -4.76721, sdlog1 = 0.399835,
     meanlog2 = 100.39362, sdlog2 = 2.583824, pmix = 0.1308133
-  ), 1.41684268426224e+46)
+  ), style = "deparse")
 })
